==> haskell-http-types-0.12.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.12.1
id: http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
key: http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
license: BSD-3-Clause
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
author: Aristid Breitkreuz, Michael Snoyman
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
abi: 48aca1d059bd297a17f6a458e8d85d56
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-types-0.12.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-types-0.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-types-0.12.1
hs-libraries: HShttp-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
depends:
    base-4.11.1.0 bytestring-0.10.8.2 array-0.5.2.0
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra text-1.2.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-types-0.12.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.12.1
id: http-types-0.12.1-1oUxUhazPUgCQ1gvXYmDkl
key: http-types-0.12.1-1oUxUhazPUgCQ1gvXYmDkl
license: BSD-3-Clause
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
author: Aristid Breitkreuz, Michael Snoyman
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
abi: af0d8a313e0ed8ed9a0049b93a58f62a
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-types-0.12.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-types-0.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-types-0.12.1
hs-libraries: HShttp-types-0.12.1-1oUxUhazPUgCQ1gvXYmDkl
depends:
    base-4.11.1.0 bytestring-0.10.8.2 array-0.5.2.0
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra text-1.2.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
